==> SemSim_1.2.0.tar.gz: SemSim/R/mtermSim.R <==
`mtermSim` <-
function(GO1, GO2, ont, measure="Resnik", db="all", multiple="max") {
    wh_ont<-match.arg(ont, c("MF", "BP", "CC"))
    wh_measure<-match.arg(measure, c("Resnik", "Lin", "Jiang", "Rel"))
    wh_db<-match.arg(db, c("all", "human", "mouse", "rat", "yeast", "plant", "microbe"))
    wh_multiple<-match.arg(multiple, c("max", "avg", "rcmax"))

    size1<-length(GO1)
    size2<-length(GO2)
    if(size1 == 0 || size2 == 0) return(NA)

    allSim<-matrix(data=NA, nrow=size1, ncol=size2)
    for( i in 1:size1 ) 
        for(j in 1:size2)
		if( Ontology(get(GO1[i], GOTERM)) == wh_ont && Ontology(get(GO2[j], GOTERM)) == wh_ont )  
 	           allSim[i, j]<-termSim(GO1[i], GO2[j], wh_measure, wh_db)

    if(!sum(!is.na(allSim))) return(NA)

    if(wh_multiple == "rcmax") { 
        rowNN<-matrix(allSim[apply(!is.na(allSim), 1, sum) > 0, ], ncol=size2)
        colNN<-matrix(allSim[, apply(!is.na(allSim), 2, sum) > 0], nrow=size1)

        rowScore<-switch(wh_measure, 
            Jiang=mean(apply(rowNN, 1, min, na.rm=T)), mean(apply(rowNN, 1, max, na.rm=TRUE)) )
        colScore<-switch(wh_measure,
	    Jiang=mean(apply(colNN, 2, min, na.rm=TRUE)), mean(apply(colNN, 2, max, na.rm=TRUE)) )

 	result<-switch(wh_measure, Jiang=min(rowScore, colScore), max(rowScore, colScore))
    } else if(wh_multiple == "max") {
	result<-switch(wh_measure, Jiang=min(allSim, na.rm=TRUE), max(allSim, na.rm=TRUE))
    } else if(wh_multiple == "avg") {
	result<-mean(allSim, na.rm=TRUE)
    } 
		
    return(round(result, digits=3))
}

==> SemSim_1.6.0.tar.gz: SemSim/R/mtermSim.R <==
`mtermSim` <-
function(GO1, GO2, ont, measure="Resnik", db="UniProt", multiple="max") {
    wh_ont<-match.arg(ont, c("MF", "BP", "CC"))
    wh_measure<-match.arg(measure, c("Resnik", "Lin", "Jiang", "Rel"))
    wh_db<-match.arg(db, c("UniProt", "human", "mouse", "rat", "plant", "yeast", "worm", "microbe"))
    wh_multiple<-match.arg(multiple, c("max", "avg", "rcmax"))

    size1<-length(GO1)
    size2<-length(GO2)
    if(size1 == 0 || size2 == 0) return(NA)

    allSim<-matrix(data=NA, nrow=size1, ncol=size2)
    for(i in 1:size1) {
        ont1<-.gocount[GO1[i], "Ont"]
	if(!is.na(ont1) && ont1 == wh_ont) { 
	    for(j in 1:size2) {
	        ont2<-.gocount[GO2[j], "Ont"]
	        if(!is.na(ont2) && ont2 == wh_ont ) {  
 	            allSim[i, j]<-.getSim(GO1[i], GO2[j], wh_ont, wh_measure, wh_db)
                }
            }
        }
    }

    if(!sum(!is.na(allSim))) return(NA)

    if(wh_multiple == "rcmax") { 
        rowNN<-matrix(allSim[apply(!is.na(allSim), 1, sum) > 0, ], ncol=size2)
        colNN<-matrix(allSim[, apply(!is.na(allSim), 2, sum) > 0], nrow=size1)

        rowScore<-switch(wh_measure, 
            Jiang=mean(apply(rowNN, 1, min, na.rm=T)), mean(apply(rowNN, 1, max, na.rm=TRUE)) )
        colScore<-switch(wh_measure,
	    Jiang=mean(apply(colNN, 2, min, na.rm=TRUE)), mean(apply(colNN, 2, max, na.rm=TRUE)) )

 	result<-switch(wh_measure, Jiang=min(rowScore, colScore), max(rowScore, colScore))
    } else if(wh_multiple == "max") {
	result<-switch(wh_measure, Jiang=min(allSim, na.rm=TRUE), max(allSim, na.rm=TRUE))
    } else if(wh_multiple == "avg") {
	result<-mean(allSim, na.rm=TRUE)
    } 
		
    return(round(result, digits=3))
}
